import './App.css'
import { Suspense, lazy, useState, useEffect, Fragment } from 'react'
import { BrowserRouter as Router, Routes, Route, Outlet, Link, NavLink } from 'react-router-dom'
import { CookiesProvider, useCookies } from 'react-cookie'

const Score = lazy(() => import('./Score'))
const Heats = lazy(() => import('./Heats'))
const Athletes = lazy(() => import('./Athletes'))
const Startlist = lazy(() => import('./Startlist'))
const Auth = lazy(() => import('./Auth'))
const AuthVerify = lazy(() => import('./AuthVerify'))
const Leaderboard = lazy(() => import('./Leaderboard'))

document.title = import.meta.env.VITE_APP_DOC_TITLE ? import.meta.env.VITE_APP_DOC_TITLE : 'My Heats'

function Layout() {
  const [session, setSession, destroySession] = useCookies(['auth'])

  return (
    <Fragment>
      <nav>
        <ul>
          <li>
            <NavLink
              className={({ isActive, isPending }) => isPending ? "pending" : isActive ? "active" : ""}
              to="/">
                Leaderboard
            </NavLink>
          </li>
          {session.auth ? <li>
            <NavLink
              className={({ isActive, isPending }) => isPending ? "pending" : isActive ? "active" : ""}
              to="/score">
                Scoring
            </NavLink>
          </li> : ''}
          {session.auth ? <li>
            <NavLink
              className={({ isActive, isPending }) => isPending ? "pending" : isActive ? "active" : ""}
              to="/heats">
                Heats and Startlists
            </NavLink>
          </li> : ''}
          {session.auth ? <li>
            <NavLink
              className={({ isActive, isPending }) => isPending ? "pending" : isActive ? "active" : ""}
              to="/athletes">
                Athletes
            </NavLink>
          </li> : ''}
        </ul>
      </nav>
      <main>
        <Outlet />
      </main>
      <footer>
        <br />
        <span className='version'>MyHeats <a href="https://code.in0rdr.ch/myheats/refs.html">v0.5</a></span>
        <span className='login'>
          {session.auth ? <button onClick={() => destroySession('auth')}>Sign out {session.auth.email}</button> :
            <NavLink
              className={({ isActive, isPending }) => isPending ? "pending" : isActive ? "active" : ""}
              to="/auth">
                Login
            </NavLink>
          }
        </span>
      </footer>
    </Fragment>
  )
}

function NoMatch() {
  return (
    <div className="NoMatch">
      Nothing to see here, <Link to="/">go to leaderboard</Link>
    </div>
  )
}

function App() {
  const [session] = useCookies(['auth'])

  return (
    <Fragment>
      <Router>
        <Suspense fallback={<div>Loading...</div>}>
          <Routes>
            <Route path="/" element={<Layout session={session} />}>
              <Route path="/" element={<Leaderboard session={session} />} />
              <Route path="/score" element={<Score session={session} />} />
              <Route path="/heats" element={<Heats session={session} />} />
              <Route path="/athletes" element={<Athletes session={session} />} />
              <Route path="/startlist/:heatId"  element={<Startlist session={session} />} />
              <Route path="/auth" element={<Auth />} />
              <Route path="/authverify" element={<AuthVerify />} />
              <Route path="*" element={<NoMatch />} />
            </Route>
          </Routes>
        </Suspense>
      </Router>
    </Fragment>
  );
}

export default App;
