const api_uri = import.meta.env.VITE_API_URI
const api_port = import.meta.env.VITE_API_PORT

export const exportHeatsToCSV = async function(e, { heats }) {
  e.preventDefault()

  // csv header
  let csv = "created_at,name,location,planned_start\n"

  // append athlete data
  for (let i = 0; i < heats.length; i++) {
    csv += heats[i].created_at + "," + heats[i].name+ "," + heats[i].location+ ","
      + heats[i].planned_start+ "\n"
  }

  exportCSV(csv, "heats")
}

export const exportAthletesToCSV = async function(e, { athletes }) {
  e.preventDefault()

  // csv header
  let csv = "created_at,nr,firstname,lastname,birthday,school\n"

  // append athlete data
  for (let i = 0; i < athletes.length; i++) {
    csv += athletes[i].created_at + "," + athletes[i].nr+ "," + athletes[i].firstname+ ","
      + athletes[i].lastname+ "," + athletes[i].birthday+ "," + athletes[i].school + "\n"
  }

  exportCSV(csv, "athletes")
}

export const exportLeaderboardToCSV = async function(e, leaderboard, heatSelection, rankingComp) {
  e.preventDefault()

  if (leaderboard.length === 0) {
    alert('Leaderboard is empty, nothing to export')
    return
  }

  // concatenate heat labels
  const heatNames = heatSelection.map(h => h.label)

  // rank leaderboard by selected comparator
  const heatSummaries = leaderboard.sort(rankByHeat(rankingComp)).map(i =>
    // for each entry i in the board, for every heat h
    heatSelection.map(h =>
      // get individual scores of the heat
      getScores(i, h) + " = "
      // get heat score sum
      + i.heats.find(heat => heat.heatId === h.value)?.summary
    )
  )

  // csv header
  let csv = "rank,start_nr,firstname,lastname,birthday,school,"
             + heatNames + "," + "best,worst,total\n"

  // append leaderboard score results
  for (let i = 0; i < leaderboard.length; i++) {
    csv += i+1 + "," + leaderboard[i].nr + "," + leaderboard[i].firstname + "," + leaderboard[i].lastname + ","
      + leaderboard[i].birthday + "," + leaderboard[i].school + ","
      + heatSummaries[i] + ","
      + leaderboard[i].bestHeat + "," + leaderboard[i].worstHeat + "," + leaderboard[i].sum + "\n"
  }

  exportCSV(csv, "scores")
}

// define the ranking logic
export const rankByHeat = function(rankingComp) {
  return function(a, b) {
    // rank by chosen heat or ranking comparator
    for (const r of rankingComp) {
      switch(r.value) {
        case 'start':
          // rank by start number
          return b.nr < a.nr
        case 'best':
          if (b.bestHeat - a.bestHeat !== 0) {
            // rank by best heat first
            return b.bestHeat - a.bestHeat
          }
          // rank by least worst heat for identical best heats
          return b.worstHeat - a.worstHeat
        case 'worst':
          // rank by worst heat
          return b.worstHeat - a.worstHeat
        case 'total':
          // rank by total sum across heats
          return b.sum - a.sum
        default:
          // rank by heat totals
          if (b.heats.find(h => h.heatId === r.value)?.summary - a.heats.find(h => h.heatId === r.value)?.summary !== 0) {
            return b.heats.find(h => h.heatId === r.value)?.summary - a.heats.find(h => h.heatId === r.value)?.summary
          }
      }
    }
  }
}

// Scores concat with "+" for leaderboard entry i and heat h
export const getScores = function(i, h) {
  const scores = i.heats.find(heat => heat.heatId === h.value)?.scores?.map(s => s.score).join(" + ")
  return scores === "" ? 0 : scores
}

// export CSV as blob
const exportCSV = function(csv, fileSlug) {
  // create blob from csv
  const blob = new Blob([csv], { type: 'text/csv;charset=utf-8;' })

  // download blob
  const url = URL.createObjectURL(blob)
  const link = document.createElement('a')
  link.href = url
  link.download = fileSlug + "-" + new Date().toISOString() + ".csv"
  document.body.appendChild(link)
  link.click()
  document.body.removeChild(link)
  // let browser know not to keep the reference to the file
  URL.revokeObjectURL(url)
}
